# Accuracy

rm(list = ls())

set.seed(15595)


# 1. Import libraries ---------------------------------------------------------------
library(dplyr)
library(readr)
library(brms)
library(tidyverse)
library(ggplot2)
library(sjPlot)
library(patchwork)
library(ggpubr)
library(marginaleffects)

theme_set(theme_pubr(base_size = 12))

# 2. Load data  ---------------------------------------------------------------

df <- read_csv("study2/data_out_2/df_acc_2.csv")%>%
  mutate(id = as.factor(id),
         tran = as.factor(ifelse(task_transition_type == "task-repetition", "rep","swi")),
         cong = as.factor(ifelse(congruency_type == "congruent", "cong", "inc")),
         rew = as.factor(ifelse(reward == "no-reward", "no","yes")),
         resp_rep = as.factor(resp_rep),
         seq = as.factor(sequence))%>%
  select(id, tran, cong, seq, rew,acc, acc_prev)


#contrast for modeling
contrasts(df$tran) <- contr.sum(2)/2;contrasts(df$tran) 
contrasts(df$cong) <- contr.sum(2)/2;contrasts(df$cong) 
contrasts(df$rew) <- contr.sum(2)/2;contrasts(df$rew) 
df$seq <- relevel(df$seq,ref = "NoInstruction")
contrasts(df$seq) 

# 3. Fit ---------------------------------------------------------------------------------
formula <- bf(acc | trials(1) ~ 1 +tran * rew * seq + cong * rew * seq + 
                (1 + tran + rew + seq + cong |id),
              family = binomial())
priors <- c(
  set_prior("normal(0, 1.5)", class = "Intercept"),
  set_prior("normal(0, 1.5)", class = "b"),
  set_prior("normal(0.5, 1)", class = "sd",lb = 0)
)


# Run model  -------------------------------------------------

mod_acc <- brm(formula = formula,
              data = df, 
              prior = priors,
              sample_prior = "yes", chains = 4,
              save_pars = save_pars(all = TRUE),
              cores = 4, iter = 6000)

# save 
save(mod_acc, file = "mod_acc_tesi.rda", 
     compress = "xz")
#---------

load("~/Desktop/Leiden/TaskSwitchFAKE/paper_modelling/study2/mod_acc_tesi.rda")

plot(mod_acc)
summary(mod_acc)
p_direction(mod_acc)
conditional_effects(mod_acc)

#tran1;seqFakeRare;seqRealRare;cong1;tran1:seqFakeRare; tran1:seqRealRare;
#seqRealRare:cong1

hypothesis(mod_acc, "tran1 = 0")
hypothesis(mod_acc, "cong1 = 0")
hypothesis(mod_acc, "rew1 = 0")
hypothesis(mod_acc, "seqFakeRare = 0")
hypothesis(mod_acc, "seqFakeFrequent = 0")
hypothesis(mod_acc, "seqRealFrequent = 0")
hypothesis(mod_acc, "seqRealRare = 0")

hypothesis(mod_acc, "tran1:rew1 = 0")
hypothesis(mod_acc, "tran1:seqFakeRare = 0")
hypothesis(mod_acc, "tran1:seqFakeFrequent = 0")
hypothesis(mod_acc, "tran1:seqRealFrequent = 0")
hypothesis(mod_acc, "tran1:seqRealRare = 0")

hypothesis(mod_acc, "seqFakeFrequent:cong1 = 0")
hypothesis(mod_acc, "seqFakeRare:cong1 = 0")
hypothesis(mod_acc, "seqRealFrequent:cong1 = 0")
hypothesis(mod_acc, "seqRealRare:cong1 = 0")

hypothesis(mod_acc, "rew1:cong1 = 0")
hypothesis(mod_acc, "rew1:seqFakeRare = 0")
hypothesis(mod_acc, "rew1:seqFakeFrequent = 0")
hypothesis(mod_acc, "rew1:seqRealFrequent = 0")
hypothesis(mod_acc, "rew1:seqRealRare = 0")


hypothesis(mod_acc, "tran1:rew1:seqFakeFrequent = 0")
hypothesis(mod_acc, "tran1:rew1:seqFakeRare = 0")
hypothesis(mod_acc, "tran1:rew1:seqRealFrequent = 0")
hypothesis(mod_acc, "tran1:rew1:seqRealRare = 0")

hypothesis(mod_acc, "rew1:seqFakeFrequent:cong1 = 0")
hypothesis(mod_acc, "rew1:seqFakeRare:cong1 = 0")
hypothesis(mod_acc, "rew1:seqRealFrequent:cong1 = 0")
hypothesis(mod_acc, "rew1:seqRealRare:cong1 = 0")



p <- avg_predictions(mod_acc, by = c("rew","tran","seq"))
three_tran <- ggplot(p, aes(x = rew, y = estimate, ymin = conf.low, ymax = conf.high, 
              col = tran, group = tran)) + facet_wrap(~seq)+
  geom_pointrange(position = position_dodge(width = 0.1))+ ylab("accuracy")+
  xlab("Reward") + ggtitle(label = "")+geom_line(size = 1, position = position_dodge(width = 0.1), alpha = 0.8) +
  ggtitle(" ")+
  scale_fill_manual(name = "Transition",values =  c("#882255","#FFA500"),
                    labels = c("Repeat","Switch")) +
  scale_color_manual(name = "Transition",values =   c("#882255","#FFA500"),
                     labels = c("Repeat","Switch"))

p <- avg_predictions(mod_acc, by = c("rew","cong","seq"))
three_cong <- ggplot(p, aes(x = rew, y = estimate, ymin = conf.low, ymax = conf.high, 
                            col = cong, group = cong)) + facet_wrap(~seq)+
  geom_pointrange(position = position_dodge(width = 0.1))+ ylab("accuracy")+
  xlab("Reward") + ggtitle(label = "")+geom_line(size = 1, position = position_dodge(width = 0.1), alpha = 0.8) +
  ggtitle(" ")+
  scale_fill_manual(name = "Congruence",values =  c("#882255","#FFA500"),
                    labels = c("Congruent","Incongruent")) +
  scale_color_manual(name = "Congruence",values =   c("#882255","#FFA500"),
                     labels = c("Congruent","Incongruent"))

p_three <- three_tran/three_cong
p_three<- p_three +  plot_annotation(tag_levels = c('A',"1"))&
  theme(plot.tag = element_text(face = 'bold'))

tiff("acc_three.png",
     width = 18, height = 25 ,units = 'cm', res = 600,
     compression = 'lzw')
p_three
dev.off()


