# DDM

rm(list = ls())

set.seed(15595)

# 1. Import libraries ---------------------------------------------------------------
library(dplyr)
library(readr)
library(brms)
library(tidyverse)


# 2. Load data  ---------------------------------------------------------------

df <- read_csv("df_acc_2.csv")%>%
  mutate(id = as.factor(id),
         tran = as.factor(ifelse(task_transition_type == "task-repetition", "rep","swi")),
         cong = as.factor(ifelse(congruency_type == "congruent", "cong", "inc")),
         rew = as.factor(ifelse(reward == "no-reward", "no","yes")),
         resp_rep = as.factor(resp_rep),
         seq = as.factor(sequence),
         rt = rt/1000)%>%
  select(id, tran, cong, seq, rew,rt,acc)%>%
  na.omit()


#contrast for modeling
contrasts(df$tran) <- contr.sum(2)/2;contrasts(df$tran) 
contrasts(df$cong) <- contr.sum(2)/2;contrasts(df$cong) 
contrasts(df$rew) <- contr.sum(2)/2;contrasts(df$rew) 
df$seq <- relevel(df$seq,ref = "NoInstruction")
contrasts(df$seq) 



# 3. Fit ---------------------------------------
## 3.1 Set Priors ------------------------------

formula <- bf(rt | dec(acc) ~ 1 + tran * rew * seq + cong * rew * seq +
                 (1 + tran + rew + seq + cong || id),
                  bs ~ 1 + rew * seq +
                 (1 + rew + seq || id),
              ndt ~ 1 + (1|id),
              bias = 0.5)

get_prior(formula,
          data = df, 
          family = wiener(link_bs = "identity", 
                          link_ndt = "identity", 
                          link_bias = "identity"))

# set priors
priors <- c(
  set_prior("normal(1.5, 2)", class = "Intercept"),
  set_prior("normal(0,.5)", class = "b"),
  set_prior("normal(1.5, 1.5)", class = "Intercept", dpar = "bs", lb = 0),
  set_prior("normal(0,.5)", class = "b",dpar = "bs"),
  set_prior("gamma(0.4, 0.2)", class = "Intercept", dpar = "ndt", lb = 0),
  set_prior("normal(0.5,0.5)",  class = "sd", lb = 0),
  set_prior("normal(0.5,0.5)", class = "sd", dpar = "bs", lb = 0))


## sampling init

tmp_dat <- make_standata(formula, 
                         family = wiener(link_bs = "identity", 
                                         link_ndt = "identity",
                                         link_bias = "identity"),
                         data = df, prior = priors)

initfun <- function() {
  list(
    Intercept = runif(1, 0.8,1.5),
    Intercept_bs = runif(1, 3, 3.5),
    Intercept_ndt = runif(1,0.1, 0.15),
    b_bs = rnorm(tmp_dat$K_bs-1,0,.0001),
    sd_1 = runif(tmp_dat$M_1, 0.05, 0.05),
    sd_2 = runif(tmp_dat$M_2, 0.05, 0.05),
    sd_3 = as.array(0.02),
    bias = 0.5)
}


# model
fit_wiener <- brm(formula, 
                  data = df,
                  family = wiener(link_bs = "identity", 
                                  link_ndt = "identity",
                                  link_bias = "identity"),
                  prior = priors, init = initfun,
                  iter = 6000, warmup = 3000,  
                  chains = 4, cores = 4,
                  sample_prior = "yes")

save(fit_wiener, file = "ddm_tesi.rda", 
     compress = "xz")


NPRED <- 500
pred_wiener <- predict(fit_wiener, 
                       summary = FALSE, 
                       negative_rt = TRUE, 
                       ndraws = NPRED, cores = 4)

save(pred_wiener, file = "postpred_ddm_tesi.rda", 
     compress = "xz")




# FAKE -------------------------------------------------

df_1 <- read_csv("df_ddm_2_trimmed.csv")%>%
  select(id,acc, crono_blocks, reward, congruency_type, task_transition_type, sequence,resp_rep,prev_cong, prev_tran,rt)%>%
  mutate(id = as.factor(id),
         congruency_type = as.factor(congruency_type),
         prev_tran = as.factor(prev_tran),
         reward = as.factor(reward),
         task_transition_type = as.factor(task_transition_type),
         sequence = sequence,
         prev_cong = as.factor(prev_cong),
         resp_rep = as.factor(resp_rep),
         rt = rt/1000,
  )%>%
  subset(sequence == "FakeFrequent" | sequence == "FakeRare")

# min(df_1$rt, na.rm = T);max(df_1$rt,df_1$rt, na.rm = T)
# mean(df_1$acc)
# hist(df_1$rt)
# hist(df_1$acc)

str(df_1)
contrasts(df_1$congruency_type) <- contr.sum(2)/2;contrasts(df_1$congruency_type)
contrasts(df_1$task_transition_type) <- contr.sum(2)/2;contrasts(df_1$task_transition_type)
contrasts(df_1$prev_tran) <- contr.sum(2)/2;contrasts(df_1$prev_tran)
contrasts(df_1$prev_cong) <- contr.sum(2)/2;contrasts(df_1$prev_cong)
contrasts(df_1$resp_rep) <- contr.sum(2)/2;contrasts(df_1$resp_rep)
df_1$sequence <- as.factor(df_1$sequence)
contrasts(df_1$sequence) <- contr.sum(2)/2;contrasts(df_1$sequence)
contrasts(df_1$reward) <- contr.sum(2)/2;contrasts(df_1$reward)



# 3. Fit ---------------------------------------
## 3.1 Set Priors ------------------------------

formula <- bf(rt | dec(acc) ~ 1 + resp_rep +
                           prev_tran * task_transition_type * sequence * reward +
                           prev_cong * congruency_type +
                           congruency_type * task_transition_type +
                           congruency_type * sequence * reward +
                 (1 + resp_rep + task_transition_type + sequence + reward +
                           congruency_type || id),
                  bs ~ 1 + resp_rep +
                           prev_tran * task_transition_type * sequence * reward +
                           prev_cong * congruency_type +
                           congruency_type * task_transition_type +
                           congruency_type * sequence * reward +
                 (1 + resp_rep + task_transition_type + sequence + reward +
                           congruency_type || id),

              ndt ~ 1 + (1|id),
              bias = 0.5)

get_prior(formula,
          data = df_1,
          family = wiener(link_bs = "identity",
                          link_ndt = "identity",
                          link_bias = "identity"))

# set priors
priors <- c(
  set_prior("normal(1.5, 2)", class = "Intercept",lb = -7, ub = 7),
  set_prior("student_t(2,0,2.5)", class = "b"),
  set_prior("normal(1.5, 1.5)", class = "Intercept", dpar = "bs", lb = 0),
  set_prior("student_t(2,0,1.5)", class = "b",dpar = "bs"),
  set_prior("gamma(0.4, 0.2)", class = "Intercept", dpar = "ndt", lb = 0),
  set_prior("gamma(1,1)",  class = "sd", lb = 0),
  set_prior("gamma(1,1)", class = "sd", dpar = "bs", lb = 0))

# check
make_stancode(formula,
              family = wiener(link_bs = "identity",
                              link_ndt = "identity",
                              link_bias = "identity"),
              data = df_1,
              prior = priors)

## sampling init

tmp_dat <- make_standata(formula,
                         family = wiener(link_bs = "identity",
                                         link_ndt = "identity",
                                         link_bias = "identity"),
                         data = df_1, prior = priors)
str(tmp_dat, 1, give.attr = FALSE)

initfun <- function() {
  list(
    Intercept = runif(1, 0.8,1.5),
    Intercept_bs = runif(1, 3, 3.5),
    Intercept_ndt = runif(1,0.1, 0.15),
    b_bs = rnorm(tmp_dat$K_bs-1,0,.0001),
    sd_1 = runif(tmp_dat$M_1, 0.05, 0.05),
    sd_2 = runif(tmp_dat$M_2, 0.05, 0.05),
    sd_3 = as.array(0.02),
    bias = 0.5)
}


# model
fit_wiener <- brm(formula,
                  data = df_1,
                  family = wiener(link_bs = "identity",
                                  link_ndt = "identity",
                                  link_bias = "identity"),
                  prior = priors, init = initfun,

 iter = 6000, warmup = 3000,
                  chains = 4, cores = 4,
                  sample_prior = "yes")

save(fit_wiener, file = "ddm_2_fake_JUNE.rda",
     compress = "xz")


NPRED <- 500
pred_wiener <- predict(fit_wiener,
                       summary = FALSE,
                       negative_rt = TRUE,
                       ndraws = NPRED, cores = 4)

save(pred_wiener, file = "postpred_ddm_2_fake_JUNE.rda",
     compress = "xz")


