# Reaction Times

rm(list = ls())

set.seed(15595)
library(brms)

# 1. Import libraries ---------------------------------------------------------------
library(dplyr)
library(readr)
library(brms)
library(tidyverse)
library(sjPlot)
library(ggplot2)

# 2. Load data  ---------------------------------------------------------------

df <- read_csv("study2/data_out_2/df_rt_2.csv")%>%
  mutate(id = as.factor(id),
         tran = as.factor(ifelse(task_transition_type == "task-repetition", "rep","swi")),
         cong = as.factor(ifelse(congruency_type == "congruent", "cong", "inc")),
         rew = as.factor(ifelse(reward == "no-reward", "no","yes")),
         resp_rep = as.factor(resp_rep),
         seq = as.factor(sequence),
         rt = rt/1000)%>%
  select(id, tran, cong, seq, rew,rt)%>%
  na.omit()


#contrast for modeling
contrasts(df$tran) <- contr.sum(2)/2;contrasts(df$tran) 
contrasts(df$cong) <- contr.sum(2)/2;contrasts(df$cong) 
contrasts(df$rew) <- contr.sum(2)/2;contrasts(df$rew) 
df$seq <- relevel(df$seq,ref = "NoInstruction")
contrasts(df$seq) 

# 3. Fit ---------------------------------------------------------------------------------
formula <- bf(rt ~ 1 +  tran * rew * seq + cong * rew * seq + 
                (1 + tran + rew + seq + cong |id),
              family = shifted_lognormal())
# 
get_prior(formula = formula, data = df)
# 

# Set weakly informative priors 
priors <- c(
  #mu
  set_prior("student_t(2, -.6, 1)", class = "Intercept", lb = -3, ub = 0),
  set_prior("normal(0, .5)", class = "b"),
  set_prior("normal(0.1,1.5)", class = "sd",lb = 0)
)


# Run model  -------------------------------------------------

mod_rt <- brm(formula = formula,
              data = df, 
              prior = priors,
              sample_prior = "yes", chains = 4,
              save_pars = save_pars(all = TRUE),
              cores = 4, iter = 6000)

# save 
save(mod_rt, file = "mod_rt_tesi.rda", 
     compress = "xz")

#---------

load("~/Desktop/Leiden/TaskSwitchFAKE/paper_modelling/study2/mod_rt_tesi.rda")

plot(mod_rt)
summary(mod_rt)
p_direction(mod_rt)
conditional_effects(mod_rt)
pp_check(mod_rt)

#tran1;seqFakeRare;seqRealRare;cong1;tran1:seqFakeRare; tran1:seqRealRare;
#seqRealRare:cong1

hypothesis(mod_rt, "tran1 = 0")
hypothesis(mod_rt, "cong1 = 0")
hypothesis(mod_rt, "rew1 = 0")
hypothesis(mod_rt, "seqFakeFrequent = 0")
hypothesis(mod_rt, "seqFakeRare = 0")
hypothesis(mod_rt, "seqRealFrequent = 0")
hypothesis(mod_rt, "seqRealRare = 0")

hypothesis(mod_rt, "tran1:seqFakeFrequent = 0")
hypothesis(mod_rt, "tran1:seqFakeRare = 0")
hypothesis(mod_rt, "tran1:seqRealFrequent = 0")
hypothesis(mod_rt, "tran1:seqRealRare = 0")

hypothesis(mod_rt, "seqFakeFrequent:cong1 = 0")
hypothesis(mod_rt, "seqFakeRare:cong1 = 0")
hypothesis(mod_rt, "seqRealFrequent:cong1 = 0")
hypothesis(mod_rt, "seqRealRare:cong1 = 0")

hypothesis(mod_rt, "tran1:rew1 = 0")
hypothesis(mod_rt, "rew1:cong1 = 0")
hypothesis(mod_rt, "rew1:seqFakeFrequent = 0")
hypothesis(mod_rt, "rew1:seqFakeRare = 0")
hypothesis(mod_rt, "rew1:seqRealFrequent = 0")
hypothesis(mod_rt, "rew1:seqRealRare = 0")


hypothesis(mod_rt, "tran1:rew1:seqFakeFrequent = 0")
hypothesis(mod_rt, "tran1:rew1:seqFakeRare = 0")
hypothesis(mod_rt, "tran1:rew1:seqRealFrequent = 0")
hypothesis(mod_rt, "tran1:rew1:seqRealRare = 0")

hypothesis(mod_rt, "rew1:seqFakeFrequent:cong1 = 0")

hypothesis(mod_rt, "rew1:seqFakeRare:cong1 = 0")
hypothesis(mod_rt, "rew1:seqRealFrequent:cong1 = 0")
hypothesis(mod_rt, "rew1:seqRealRare:cong1 = 0")

options("marginaleffects_posterior_interval" = "hdi")
options("marginaleffects_posterior_center" = "mean")

p <- avg_predictions(mod_rt, by = c("rew","tran","seq"))
three_tran <- ggplot(p, aes(x = rew, y = estimate, ymin = conf.low, ymax = conf.high, 
                            col = tran, group = tran)) + facet_wrap(~seq)+
  geom_errorbar(position = position_dodge(width = 0.1), width = .4)+ ylab("reaction times")+
  geom_pointrange(position = position_dodge(width = 0.1), size = .2)+
  xlab("Reward") + ggtitle(label = "")+geom_line(size = .8, position = position_dodge(width = 0.1), alpha = 0.7) +
  ggtitle(" ")+
  scale_fill_manual(name = "Transition",values =  c("#882255","#FFA500"),
                    labels = c("Repeat","Switch")) +
  scale_color_manual(name = "Transition",values =   c("#882255","#FFA500"),
                     labels = c("Repeat","Switch"))

p <- avg_predictions(mod_rt, by = c("rew","cong","seq"))
three_cong <- ggplot(p, aes(x = rew, y = estimate, ymin = conf.low, ymax = conf.high, 
                            col = cong, group = cong)) + facet_wrap(~seq)+
  geom_errorbar(position = position_dodge(width = 0.1), width = .4)+ ylab("reaction times")+
  geom_pointrange(position = position_dodge(width = 0.1), size = .2)+
  xlab("Reward") + ggtitle(label = "")+geom_line(size = .8, position = position_dodge(width = 0.1), alpha = 0.7) +
  ggtitle(" ")+
  scale_fill_manual(name = "Congruence",values =  c("#882255","#FFA500"),
                    labels = c("Congruent","Incongruent")) +
  scale_color_manual(name = "Congruence",values =   c("#882255","#FFA500"),
                     labels = c("Congruent","Incongruent"))

p_three <- three_tran/three_cong
p_three<- p_three +  plot_annotation(tag_levels = c('A',"1"))&
  theme(plot.tag = element_text(face = 'bold'))

tiff("rt_three.png",
     width = 18, height = 25 ,units = 'cm', res = 600,
     compression = 'lzw')
p_three
dev.off()

# Contrast ----------------------------------------------
emm_rt = mod_rt %>%
  emmeans(~ cong + seq + rew)|>
  gather_emmeans_draws()|>
  subset(seq == "NoInstruction" | seq == "FakeFrequent")


drw = list(cong_no_norew = (emm_rt$.value[1:12000]),
           in_no_norew = (emm_rt$.value[12001:24000]),
           cong_fa_norew = (emm_rt$.value[24001:36000]),
           in_fa_norew = (emm_rt$.value[36001:48000]),
           cong_no_rew = (emm_rt$.value[48001:60000]),
           in_no_rew = (emm_rt$.value[60001:72000]),
           cong_fa_rew = (emm_rt$.value[72001:84000]),
           in_fa_rew = (emm_rt$.value[84001:96000]))

no_norew <- drw$cong_no_norew - drw$in_no_norew
fa_norew <- drw$cong_fa_norew -  drw$in_fa_norew
no_rew <- drw$cong_no_rew -  drw$in_no_rew
fa_rew <- drw$cong_fa_rew -  drw$in_fa_rew

d_norew = no_norew - fa_norew
d_rew = no_rew - fa_rew

hdi(d_norew);round(mean(d_norew),2);mean(d_norew<0)
hdi(d_rew);round(mean(d_rew),2);mean(d_rew>0)
savage.dickey.bf(d_norew, x_0 = 0, prior.mean = 0, prior.sd=0.5, plot=T)
savage.dickey.bf(d_rew, x_0 = 0, prior.mean = 0, prior.sd=0.5, plot=T)

